@@ -72,7 +72,8 @@ class Element(ModelRefMixin, ModelItem, ABC):
         self.name = name
         self.description = description
         self.url = url
-        # Note: relationships should always match get_efferent_relationships() - i.e. outbound relationships only
+        # Note: relationships should always match get_efferent_relationships() - i.e.
+        # outbound relationships only
         self.relationships: Iterable[Relationship] = set(relationships)
 
         self.tags.add(Tags.ELEMENT)
@@ -100,13 +101,18 @@ class Element(ModelRefMixin, ModelItem, ABC):
         )
 
     def add_relationship(
-        self, relationship: Optional[Relationship] = None, **kwargs
+        self,
+        relationship: Optional[Relationship] = None,
+        *,
+        create_implied_relationships: bool = True,
+        **kwargs,
     ) -> Relationship:
         """Add a new relationship from this element to another.
 
-        This can be used either to add a `Relationship` instance that has already been constructed,
-        or by passing the arguments (e.g. description, destination) with which to construct a new
-        one.  The relationship will automatically be registered with the element's model.
+        This can be used either to add a `Relationship` instance that has already been
+        constructed, or by passing the arguments (e.g. description, destination) with
+        which to construct a new one.  The relationship will automatically be
+        registered with the element's model.
         """
         if relationship is None:
             relationship = Relationship(**kwargs)
@@ -116,14 +122,18 @@ class Element(ModelRefMixin, ModelItem, ABC):
             relationship.source = self
         elif relationship.source is not self:
             raise ValueError(
-                f"Cannot add relationship {relationship} to element {self} that is not its source."
+                f"Cannot add relationship {relationship} to element {self} that is "
+                f"not its source."
             )
         self.relationships.add(relationship)
-        self.get_model().add_relationship(relationship)
+        self.model.add_relationship(
+            relationship, create_implied_relationships=create_implied_relationships
+        )
         return relationship
 
     @classmethod
     def hydrate_arguments(cls, element_io: ElementIO) -> dict:
+        """Hydrate an ElementIO into the constructor arguments for Element."""
         return {
             **super().hydrate_arguments(element_io),
             "name": element_io.name,
