@@ -22,7 +22,7 @@ from typing import TYPE_CHECKING, Optional
 from .element import Element, ElementIO
 
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from .relationship import Relationship
 
 
@@ -53,10 +53,11 @@ class StaticStructureElement(Element, ABC):
     def uses(
         self,
         destination: Element,
-        description: str,
+        description: str = "Uses",
         technology: str = "",
         **kwargs,
     ) -> Optional["Relationship"]:
+        """Add a unidirectional "uses" style relationship to another element."""
         return self.get_model().add_relationship(
             source=self,
             destination=destination,
@@ -72,6 +73,7 @@ class StaticStructureElement(Element, ABC):
         technology: str = "",
         **kwargs,
     ) -> Optional["Relationship"]:
+        """Add a unidirectional relationship to another element."""
         return self.uses(
             destination=destination,
             description=description,
